# New in 0.17.1 (2022-07-14)

Make sure notebooks are up to date for real this time :).

## Contributors

-   [@jjhong922]
-   [@adamgayoso]

[@jjhong922]: https://github.com/jjhong922
[@adamgayoso]: https://github.com/adamgayoso
